@@ -194,7 +194,7 @@ def sh (command, header = None, output = True, timeout = None):
         (stdout, error) = cProcess.communicate()
         signal.alarm(0)
     except Alarm:
-        console.warn('taking too long')
+        console.warn('taking too long (%s)' % command)
         cProcess.kill()
         stdout = error = ""
    
